#include "resource.h"
#include <windows.h>
#include <commctrl.h>

typedef struct {
char title[31];
char artist[31];
char album[31];
char year[5];
char comment[29];
unsigned short track;
unsigned short genre;
} ID3V11STRUCT, *LPID3V11STRUCT;

extern "C" __declspec(dllexport) char filterStr[] = "MP3 Files (*.mp3)\0*.mp3\0";

int GetID3v11Info(HANDLE hFile, LPID3V11STRUCT lpIvs);
int SetID3v11Info(HANDLE hFile, LPID3V11STRUCT lpIvs);
int RemoveID3v11Tag(HANDLE hFile);
void FillGenreComboBox(HWND hwnd);
void EnableItems(HWND hwnd);
void DisableItems(HWND hwnd);

BOOL CALLBACK Mp3DlgProc(HWND hwnd, UINT Message, WPARAM wParam, LPARAM lParam) {
static HANDLE hFile;
switch(Message) {
	case WM_INITDIALOG:
	{
	SendMessage(hwnd, WM_SETICON, ICON_SMALL, (LPARAM)LoadImage(GetModuleHandle(NULL), MAKEINTRESOURCE(IDI_MAIN), IMAGE_ICON, 16, 16, 0));
	SendMessage(hwnd, WM_SETICON, ICON_BIG, (LPARAM)LoadImage(GetModuleHandle(NULL), MAKEINTRESOURCE(IDI_MAIN), IMAGE_ICON, 32, 32, 0));
	hFile = (HANDLE)lParam;
	ID3V11STRUCT ivs;
	int ret = GetID3v11Info(hFile, &ivs);
	if (!ret) {
	MessageBox(hwnd, "Could not read from file!", "Error", MB_ICONEXCLAMATION | MB_OK);
	EndDialog(hwnd, 0);
	break;
	}
	FillGenreComboBox(hwnd);
	SendDlgItemMessage(hwnd, IDE_TRACK, EM_LIMITTEXT, (WPARAM)3, 0);
	SendDlgItemMessage(hwnd, IDE_TITLE, EM_LIMITTEXT, (WPARAM)30, 0);
	SendDlgItemMessage(hwnd, IDE_ARTIST, EM_LIMITTEXT, (WPARAM)30, 0);
	SendDlgItemMessage(hwnd, IDE_ALBUM, EM_LIMITTEXT, (WPARAM)30, 0);
	SendDlgItemMessage(hwnd, IDE_YEAR, EM_LIMITTEXT, (WPARAM)4, 0);
	SendDlgItemMessage(hwnd, IDE_COMMENT, EM_LIMITTEXT, (WPARAM)28, 0);
	if (ret == 1) break;
	if (ret == 2) {
	SendDlgItemMessage(hwnd, IDB_ID3TAG, BM_SETCHECK, (WPARAM)BST_CHECKED, 0);
	EnableItems(hwnd);
	SetDlgItemInt(hwnd, IDE_TRACK, ivs.track, false);
	SetDlgItemText(hwnd, IDE_TITLE, ivs.title);
	SetDlgItemText(hwnd, IDE_ARTIST, ivs.artist);
	SetDlgItemText(hwnd, IDE_ALBUM, ivs.album);
	SetDlgItemText(hwnd, IDE_YEAR, ivs.year);
	SetDlgItemText(hwnd, IDE_COMMENT, ivs.comment);
	if (ivs.genre == 0xFF) SendDlgItemMessage(hwnd, IDC_GENRE, CB_SETCURSEL, (WPARAM)0, 0);
	else SendDlgItemMessage(hwnd, IDC_GENRE, CB_SETCURSEL, (WPARAM)(ivs.genre + 1), 0);
	}
	}
	break;
	case WM_COMMAND:
	switch(LOWORD(wParam)) {
		case IDB_ID3TAG:
		switch (SendDlgItemMessage(hwnd, IDB_ID3TAG, BM_GETCHECK, 0, 0)) {
			case BST_CHECKED:
			EnableItems(hwnd);
			break;
			case BST_UNCHECKED:
			DisableItems(hwnd);
			break;
		}
		break;
		case IDB_SAVE:
		switch (SendDlgItemMessage(hwnd, IDB_ID3TAG, BM_GETCHECK, 0, 0)) {
			case BST_CHECKED:
			{
			ID3V11STRUCT ivs;
			ZeroMemory(&ivs, sizeof(ID3V11STRUCT));
			ivs.track = GetDlgItemInt(hwnd, IDE_TRACK, NULL, false);
			GetDlgItemText(hwnd, IDE_TITLE, ivs.title, 30);
			GetDlgItemText(hwnd, IDE_ARTIST, ivs.artist, 30);
			GetDlgItemText(hwnd, IDE_ALBUM, ivs.album, 30);
			GetDlgItemText(hwnd, IDE_YEAR, ivs.year, 4);
			GetDlgItemText(hwnd, IDE_COMMENT, ivs.comment, 28);
			int gen = SendDlgItemMessage(hwnd, IDC_GENRE, CB_GETCURSEL, 0, 0);
			if (gen == CB_ERR || gen == 0) ivs.genre = 0xFF;
			else ivs.genre = gen - 1;
			if (!SetID3v11Info(hFile, &ivs)) MessageBox(hwnd, "Could not write to file!", "Error", MB_ICONEXCLAMATION | MB_OK);
			}
			break;
			case BST_UNCHECKED:
			RemoveID3v11Tag(hFile);
			break;
		}
		break;
		case IDB_CLOSE:
		EndDialog(hwnd, 0);
		break;
	}
	break;
	case WM_CLOSE:
	EndDialog(hwnd, 0);
	break;
	default:
	return FALSE;
}
return TRUE;
}

extern "C" __declspec(dllexport) int LoadFile(HANDLE hFile, HWND hwnd, HMODULE hModule) {
InitCommonControls();
int ret = DialogBoxParam(hModule, MAKEINTRESOURCE(IDD_MP3), hwnd, Mp3DlgProc, (LPARAM)hFile);
return ret;
}
	
int GetID3v11Info(HANDLE hFile, LPID3V11STRUCT lpIvs) {
ZeroMemory(lpIvs, sizeof(ID3V11STRUCT));
SetFilePointer(hFile, -128, NULL, FILE_END);
char tag[128];
DWORD unused;
if (!ReadFile(hFile, tag, 128, &unused, NULL)) return 0;
if (tag[0] != 'T' || tag[1] != 'A' || tag[2] != 'G') return 1;
int i;
for (i=0;i<30;i++) lpIvs->title[i] = tag[3 + i];
for (i=0;i<30;i++) lpIvs->artist[i] = tag[33 + i];
for (i=0;i<30;i++) lpIvs->album[i] = tag[63 + i];
for (i=0;i<4;i++) lpIvs->year[i] = tag[93 + i];
for (i=0;i<28;i++) lpIvs->comment[i] = tag[97 + i];
lpIvs->track = (unsigned short)tag[126];
lpIvs->genre = (unsigned short)tag[127];
return 2;
}

int SetID3v11Info(HANDLE hFile, LPID3V11STRUCT lpIvs) {
char tag[128];
ZeroMemory(tag, 128);
int i;
tag[0] = 'T';
tag[1] = 'A';
tag[2] = 'G';
for (i=0;i<30;i++) tag[3 + i] = lpIvs->title[i];
for (i=0;i<30;i++) tag[33 + i] = lpIvs->artist[i];
for (i=0;i<30;i++) tag[63 + i] = lpIvs->album[i];
for (i=0;i<4;i++) tag[93 + i] = lpIvs->year[i];
for (i=0;i<28;i++) tag[97 + i] = lpIvs->comment[i];
tag[126] = (char)lpIvs->track;
tag[127] = (char)lpIvs->genre;
char temp[3];
SetFilePointer(hFile, -128, NULL, FILE_END);
DWORD unused;
ReadFile(hFile, temp, 3, &unused, NULL);
if (temp[0] != 'T' || temp[1] != 'A' || temp[2] != 'G') {
SetFilePointer(hFile, 0, NULL, FILE_END);
if (!WriteFile(hFile, tag, 128, &unused, NULL)) return 0;
SetEndOfFile(hFile);
} else {
SetFilePointer(hFile, -128, NULL, FILE_END);
if (!WriteFile(hFile, tag, 128, &unused, NULL)) return 0;
}
return 1;
}

int RemoveID3v11Tag(HANDLE hFile) {
SetFilePointer(hFile, -128, NULL, FILE_END);
char temp[3];
DWORD unused;
ReadFile(hFile, temp, 3, &unused, NULL);
if (temp[0] != 'T' || temp[1] != 'A' || temp[2] != 'G') return 1;
SetFilePointer(hFile, -128, NULL, FILE_END);
SetEndOfFile(hFile);
return 1;
}

void FillGenreComboBox(HWND hwnd) {
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Blues");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Classic Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Country");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Dance");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Disco");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Funk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Grunge");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Hip-Hop");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Jazz");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Metal");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"New Age");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Oldies");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Other");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Pop");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"R&B");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Rap");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Reggae");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Techno");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Industrial");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Alternative");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Ska");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Death Metal");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Pranks");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Soundtrack");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Eurotechno");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Ambient");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Trip-Hop");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Vocal");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Jazz+Funk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Fusion");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Trance");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Classical");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Instrumental");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Acid");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"House");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Game");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Sound Clip");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Gospel");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Noise");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Alternative Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Bass");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Soul");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Punk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Space");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Meditative");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Instrumental Pop");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Instrumental Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Ethnic");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Gothic");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Darkwave");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Techno-Industrial");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Electronic");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Jungle");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Pop-Folk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Eurodance");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Dream");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Southern Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Comedy");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Cult");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Gangsta");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Top 40");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Christian Rap");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Pop/Funk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Native American");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Cabaret");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"New Wave");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Psychadelic");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Rave");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Show Tunes");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Trailer");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Lo-Fi");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Tribal");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Acid Punk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Acid Jazz");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Polka");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Retro");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Musical");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Rock & Roll");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Hard Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Folk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Folk/Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"National Folk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Swing");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Fast-Fusion");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Bebop");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Latin");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Revival");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Celtic");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Bluegrass");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Avantgarde");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Gothic Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Progressive Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Psychedelic Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Symphonic Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Slow Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Big Band");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Chorus");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Easy Listening");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Acoustic");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Humor");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Speech");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Chanson");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Opera");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Chamber Music");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Sonata");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Symphony");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Booty Bass");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Primus");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Porn Groove");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Satire");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Slow Jam");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Club");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Tango");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Samba");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Folklore");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Ballad");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Power Ballad");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Rhytmic Soul");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Freestyle");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Duet");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Punk Rock");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Drum Solo");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Acapella");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Euro-House");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Dance Hall");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Goa");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Drum & Bass");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Club-House");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Hardcore");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Terror");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Indie");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"BritPop");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Negerpunk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Polsk Punk");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Beat");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Christian Gangsta Rap");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Heavy Metal");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Black Metal");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Crossover");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Contemporary Christian");
SendDlgItemMessage(hwnd, IDC_GENRE, CB_ADDSTRING, 0, (LPARAM)"Christian Rock"); //141
}

void EnableItems(HWND hwnd) {
EnableWindow(GetDlgItem(hwnd, IDE_TRACK), true);
EnableWindow(GetDlgItem(hwnd, IDE_TITLE), true);
EnableWindow(GetDlgItem(hwnd, IDE_ARTIST), true);
EnableWindow(GetDlgItem(hwnd, IDE_ALBUM), true);
EnableWindow(GetDlgItem(hwnd, IDE_YEAR), true);
EnableWindow(GetDlgItem(hwnd, IDC_GENRE), true);
EnableWindow(GetDlgItem(hwnd, IDE_COMMENT), true);
}

void DisableItems(HWND hwnd) {
EnableWindow(GetDlgItem(hwnd, IDE_TRACK), false);
EnableWindow(GetDlgItem(hwnd, IDE_TITLE), false);
EnableWindow(GetDlgItem(hwnd, IDE_ARTIST), false);
EnableWindow(GetDlgItem(hwnd, IDE_ALBUM), false);
EnableWindow(GetDlgItem(hwnd, IDE_YEAR), false);
EnableWindow(GetDlgItem(hwnd, IDC_GENRE), false);
EnableWindow(GetDlgItem(hwnd, IDE_COMMENT), false);
}
